"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.convert = exports.convertMulti = void 0;
const ajv_1 = __importDefault(require("ajv"));
const assert_1 = __importDefault(require("assert"));
const behaveConverter_1 = require("./behave/behaveConverter");
const BehaveSchema_1 = __importDefault(require("./behave/BehaveSchema"));
const cucumberJsConverter_1 = require("./cucumber-js/cucumberJsConverter");
const CucumberJsSchema_1 = __importDefault(require("./cucumber-js/CucumberJsSchema"));
const cucumberJvmConverter_1 = require("./cucumber-jvm/cucumberJvmConverter");
const CucumberJvmSchema_1 = __importDefault(require("./cucumber-jvm/CucumberJvmSchema"));
const cucumberRubyConverter_1 = require("./cucumber-ruby/cucumberRubyConverter");
const CucumberRubySchema_1 = __importDefault(require("./cucumber-ruby/CucumberRubySchema"));
const CucumberSchema_1 = __importDefault(require("./CucumberSchema"));
const implementationConverterBySchema = new Map();
implementationConverterBySchema.set(BehaveSchema_1.default, behaveConverter_1.behaveConverter);
implementationConverterBySchema.set(CucumberJsSchema_1.default, cucumberJsConverter_1.cucumberJsConverter);
implementationConverterBySchema.set(CucumberJvmSchema_1.default, cucumberJvmConverter_1.cucumberJvmConverter);
implementationConverterBySchema.set(CucumberRubySchema_1.default, cucumberRubyConverter_1.cucumberRubyConverter);
const resultValidator = new ajv_1.default().compile(CucumberSchema_1.default);
const convalidators = [];
for (const [implementationSchema, converter] of implementationConverterBySchema.entries()) {
    const implementationValidator = new ajv_1.default().compile(implementationSchema);
    const resultValidatingConverter = (obj) => {
        const converted = converter(obj);
        if (resultValidator(converted)) {
            return converted;
        }
        else {
            const error = `Error from ${implementationSchema.$ref} validation: ${JSON.stringify(resultValidator.errors, null, 2)}`;
            const convertedJson = JSON.stringify(converted, null, 2);
            throw new Error(`Could not validate converted Cucumber JSON.\n${error}\nConverted JSON:${convertedJson}`);
        }
    };
    convalidators.push({
        implementationValidator,
        converter: resultValidatingConverter,
        schema: implementationSchema,
    });
}
function convertMulti(data) {
    const errors = [];
    const candidateConvalidators = convalidators.filter((convalidator) => {
        const validator = convalidator.implementationValidator;
        const schema = convalidator.schema;
        if (validator(data)) {
            return true;
        }
        else {
            const error = `Errors from ${schema.$ref} validation: ${JSON.stringify(validator.errors, null, 2)}`;
            // console.log(error)
            errors.push(error);
        }
    });
    if (candidateConvalidators.length === 0) {
        throw new Error(`Could not validate Cucumber JSON.\n${errors.join('\n')}`);
    }
    return candidateConvalidators.map((convalidator) => convalidator.converter(data));
}
exports.convertMulti = convertMulti;
function convert(data) {
    const cucumberJsons = convertMulti(data);
    if (cucumberJsons.length > 1) {
        // Sanity check that all the conversions have the same result
        for (let n = 1; n < cucumberJsons.length; n++) {
            const cucumberJson1 = cucumberJsons[n - 1];
            const cucumberJson2 = cucumberJsons[n];
            assert_1.default.deepStrictEqual(withoutImplementation(cucumberJson1), withoutImplementation(cucumberJson2), "The platform-specifc Cucumber JSON was valid against multiple JSON schemas, and wasn't consistently converted");
        }
    }
    return cucumberJsons[0];
}
exports.convert = convert;
function withoutImplementation(cucumberJson) {
    const copy = JSON.parse(JSON.stringify(cucumberJson));
    copy.implementation = '';
    return copy;
}
//# sourceMappingURL=convert.js.map