"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cucumberJsConverter = void 0;
const cucumberJsConverter = (json) => {
    return {
        implementation: 'cucumber-js',
        features: json.map(jsFeatureToFeature),
    };
};
exports.cucumberJsConverter = cucumberJsConverter;
function jsFeatureToFeature(jsFeature) {
    return {
        ...jsFeature,
        ...{
            elements: jsFeature.elements.map(jsElementToElement),
        },
    };
}
function jsElementToElement(jsElement) {
    const before = jsElement.steps.filter(isBeforeHook).map(hookStepToHook);
    const steps = jsElement.steps.filter(isStep).map(jsStepToStep);
    const after = jsElement.steps.filter(isAfterHook).map(hookStepToHook);
    return {
        after,
        before,
        description: jsElement.description || '',
        id: jsElement.id,
        keyword: jsElement.keyword,
        line: jsElement.line,
        name: jsElement.name,
        steps,
        tags: jsElement.tags,
        type: jsElement.type || 'scenario',
    };
}
function jsStepToStep(jsStep) {
    const docStrings = (jsStep.arguments || []).filter(isDocstring).map((docString) => ({
        line: docString.line,
        value: docString.content,
    }));
    const datatables = (jsStep.arguments || []).filter(isDataTable);
    return {
        keyword: jsStep.keyword,
        line: jsStep.line,
        name: jsStep.name,
        result: jsStep.result,
        match: jsStep.match,
        doc_string: docStrings.length > 0 ? docStrings[0] : undefined,
        rows: datatables.length > 0 ? datatables[0].rows : undefined,
    };
}
function hookStepToHook(jsHook) {
    return {
        result: jsHook.result,
    };
}
function isStep(jsStepOrHook) {
    return !('hidden' in jsStepOrHook);
}
function isBeforeHook(jsStepOrHook) {
    return 'hidden' in jsStepOrHook && jsStepOrHook.keyword === 'Before';
}
function isAfterHook(jsStepOrHook) {
    return 'hidden' in jsStepOrHook && jsStepOrHook.keyword === 'After';
}
function isDocstring(argument) {
    return argument.content !== undefined;
}
function isDataTable(argument) {
    return !isDocstring(argument);
}
//# sourceMappingURL=cucumberJsConverter.js.map